# Generated by Django 5.2.1 on 2025-11-18 12:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ichec_django_core", "0002_memberidentifier"),
    ]

    operations = [
        migrations.AlterField(
            model_name="formfieldvalue",
            name="value",
            field=models.CharField(blank=True, max_length=500),
        ),
    ]
