# Generated by Django 5.2.1 on 2025-11-13 08:12

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ichec_django_core", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="MemberIdentifier",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "id_type",
                    models.CharField(
                        choices=[("ORCID", "ORCID"), ("FREEFORM", "Freeform")],
                        max_length=8,
                    ),
                ),
                ("value", models.CharField(max_length=48)),
                (
                    "member",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="identifiers",
                        to="ichec_django_core.member",
                    ),
                ),
            ],
        ),
    ]
